@@ -398,12 +398,12 @@ ms_read_TXO (BiffQuery *q, MSContainer *c, PangoAttrList **markup)
 		"Top to Bottom on Side"
 	};
 	static char const * const haligns [] = {
-		"At left", "Horizontaly centered",
-		"At right", "Horizontaly justified"
+		"At left", "Horizontally centered",
+		"At right", "Horizontally justified"
 	};
 	static char const * const valigns [] = {
-		"At top", "Verticaly centered",
-		"At bottom", "Verticaly justified"
+		"At top", "Vertically centered",
+		"At bottom", "Vertically justified"
 	};
 
 	guint16 options, orient, text_len;
@@ -938,6 +938,9 @@ ms_obj_map_forms_obj (MSObj *obj, MSContainer *c,
 		if (map_forms [i].excel_type > 0 &&
 		    !strcmp (type+6, map_forms[i].key))
 			break;
+
+	g_free (type);
+
 	if (i < 0)
 		return;
 	obj->excel_type = map_forms [i].excel_type;
