@@ -129,23 +129,11 @@ xlsx_write_rgbarea (GsfXMLOut *xml, GOColor color)
 }
 
 static void
-xlsx_write_go_style (GsfXMLOut *xml, GOStyle *style)
+xlsx_write_go_style_full (GsfXMLOut *xml, GOStyle *style,
+			  gboolean def_has_markers)
 {
 	gsf_xml_out_start_element (xml, "c:spPr");
-	if ((style->interesting_fields & (GO_STYLE_LINE | GO_STYLE_OUTLINE)) &&
-	    style->line.dash_type != GO_LINE_NONE) {/* TODO: add more tests for transparent line */
-		/* export the line color */
-		gsf_xml_out_start_element (xml, "a:ln");
-		if (style->line.width > 0)
-			gsf_xml_out_add_int (xml, "w", style->line.width * 12700);
-		if (!style->line.auto_color) {
-			gsf_xml_out_start_element (xml, "a:solidFill");
-			xlsx_write_rgbarea (xml, style->line.color);
-			gsf_xml_out_end_element (xml);
-		}
 
-		gsf_xml_out_end_element (xml);
-	}
 	if ((style->interesting_fields & GO_STYLE_FILL) &&
 	    style->fill.type != GO_STYLE_FILL_NONE) {/* TODO add tests for transparent backgrounds */
 		switch (style->fill.type) {
@@ -175,75 +163,365 @@ xlsx_write_go_style (GsfXMLOut *xml, GOStyle *style)
 			break;
 		}
 	}
-	gsf_xml_out_end_element (xml);
+
+	if ((style->interesting_fields & (GO_STYLE_LINE | GO_STYLE_OUTLINE)) &&
+	    (!style->line.auto_dash ||
+	     !style->line.auto_width ||
+	     !style->line.auto_color)) {
+		static const char * const dashes[] = {
+			NULL,            /* GO_LINE_NONE */
+			"solid",         /* GO_LINE_SOLID */
+			"sysDot",        /* GO_LINE_S_DOT */
+			"sysDashDot",    /* GO_LINE_S_DASH_DOT */
+			"sysDashDotDot", /* GO_LINE_S_DASH_DOT_DOT */
+			"lgDashDotDot",  /* GO_LINE_DASH_DOT_DOT_DOT */
+			"dot",           /* GO_LINE_DOT */
+			"sysDash",       /* GO_LINE_S_DASH */
+			"dash",          /* GO_LINE_DASH */
+			"lgDash",        /* GO_LINE_LONG_DASH */
+			"dashDot",       /* GO_LINE_DASH_DOT */
+			"lgDashDot",     /* GO_LINE_DASH_DOT_DOT */
+		};
+		gboolean is_none = (style->line.dash_type == GO_LINE_NONE);
+
+		gsf_xml_out_start_element (xml, "a:ln");
+		if (is_none) {
+			/* Special meaning of zero width  */
+			gsf_xml_out_add_int (xml, "w", 0);
+		} else if (!style->line.auto_width && style->line.width > 0)
+			gsf_xml_out_add_int (xml, "w", style->line.width * 12700);
+
+		if (!style->line.auto_color) {
+			gsf_xml_out_start_element (xml, "a:solidFill");
+			xlsx_write_rgbarea (xml, style->line.color);
+			gsf_xml_out_end_element (xml);
+		}
+
+		if (!style->line.auto_dash &&
+		    style->line.dash_type < G_N_ELEMENTS (dashes) &&
+		    dashes[style->line.dash_type]) {
+			xlsx_write_chart_cstr_unchecked (xml,
+							 "a:prstDash",
+							 dashes[style->line.dash_type]);
+		}
+
+		gsf_xml_out_end_element (xml);
+	}
+
+	gsf_xml_out_end_element (xml);  /* "c:spPr" */
+
 	if (style->interesting_fields & GO_STYLE_MARKER) {
+		static const char *const markers[] = {
+			"none",       /* GO_MARKER_NONE */
+			"square",     /* GO_MARKER_SQUARE */
+			"diamond",    /* GO_MARKER_DIAMOND */
+			"triangle",   /* GO_MARKER_TRIANGLE_DOWN */   /* FIXME: rotation */
+			"triangle",   /* GO_MARKER_TRIANGLE_UP */
+			"triangle",   /* GO_MARKER_TRIANGLE_RIGHT */  /* FIXME: rotation */
+			"triangle",   /* GO_MARKER_TRIANGLE_LEFT */   /* FIXME: rotation */
+			"circle",     /* GO_MARKER_CIRCLE */
+			"x",          /* GO_MARKER_X */
+			"plus",       /* GO_MARKER_CROSS */
+			"star",       /* GO_MARKER_ASTERISK */
+			"dash",       /* GO_MARKER_BAR */
+			"dot",        /* GO_MARKER_HALF_BAR */
+			"diamond",    /* GO_MARKER_BUTTERFLY */       /* FIXME: dubious */
+			"diamond",    /* GO_MARKER_HOURGLASS */       /* FIXME: dubious */
+			"dot"         /* GO_MARKER_LEFT_HALF_BAR */
+		};
+		gboolean need_spPr;
+		GOMarkerShape s = style->marker.auto_shape
+			? (def_has_markers ? GO_MARKER_MAX : GO_MARKER_NONE)
+			: go_marker_get_shape (style->marker.mark);
+
+		gsf_xml_out_start_element (xml, "c:marker");
+
+		xlsx_write_chart_cstr_unchecked
+			(xml, "c:symbol",
+			 (s < G_N_ELEMENTS (markers) && markers[s]
+			  ? markers[s]
+			  : "auto"));
+
+		/* We don't have an auto_size flag */
+		if (TRUE) {
+			int def = 5, s = go_marker_get_size (style->marker.mark);
+			xlsx_write_chart_int (xml, "c:size", def, s);
+		}
+
+		need_spPr = (!style->marker.auto_fill_color ||
+			     !style->marker.auto_outline_color);
+		if (need_spPr) {
+			gsf_xml_out_start_element (xml, "c:spPr");
+
+			if (!style->marker.auto_fill_color) {
+				gsf_xml_out_start_element (xml, "a:solidFill");
+				xlsx_write_rgbarea (xml, go_marker_get_fill_color (style->marker.mark));
+				gsf_xml_out_end_element (xml);
+			}
+
+			if (!style->marker.auto_outline_color) {
+				gsf_xml_out_start_element (xml, "a:ln");
+				gsf_xml_out_start_element (xml, "a:solidFill");
+				xlsx_write_rgbarea (xml, go_marker_get_outline_color (style->marker.mark));
+				gsf_xml_out_end_element (xml);
+				gsf_xml_out_end_element (xml);
+			}
+
+			gsf_xml_out_end_element (xml);
+		}
+
+		gsf_xml_out_end_element (xml);
 	}
 }
 
+static void
+xlsx_write_go_style (GsfXMLOut *xml, GOStyle *style)
+{
+	xlsx_write_go_style_full (xml, style, FALSE);
+}
+
+static void
+xlsx_write_chart_text (XLSXWriteState *state, GsfXMLOut *xml,
+		       GOData *data, GogObject const *label)
+{
+	/* I don't really know what I am doing here.  */
+	char *text = go_data_get_scalar_string (data);
+	GOStyle *style = go_styled_object_get_style (GO_STYLED_OBJECT (label));
+	gboolean has_font_color = ((style->interesting_fields & GO_STYLE_FONT) &&
+				   !style->font.auto_color);
+	gboolean has_font = ((style->interesting_fields & GO_STYLE_FONT) &&
+			     TRUE /* !style->font.auto_font */);
+	gboolean allow_wrap;
+
+	gsf_xml_out_start_element (xml, "c:tx");
+	gsf_xml_out_start_element (xml, "c:rich");
+
+	gsf_xml_out_start_element (xml, "a:bodyPr");
+	g_object_get (G_OBJECT (label), "allow-wrap", &allow_wrap, NULL);
+	if (!allow_wrap)
+		gsf_xml_out_add_cstr_unchecked (xml, "wrap", "none");
+	gsf_xml_out_end_element (xml); /* </a:bodyPr> */
+
+	gsf_xml_out_start_element (xml, "a:p");
+	gsf_xml_out_start_element (xml, "a:r");
+
+	if (has_font_color || has_font) {
+		GOFont const *font = style->font.font;
+		PangoFontDescription *desc = font->desc;
+
+		gsf_xml_out_start_element (xml, "a:rPr");
+		if (has_font) {
+			int sz = pango_font_description_get_size (desc);
+			if (sz > 0) {
+				sz = CLAMP (sz, 1 * PANGO_SCALE, 4000 * PANGO_SCALE);
+				gsf_xml_out_add_uint (xml, "sz", sz * 100 / PANGO_SCALE);
+			}
+
+			if (pango_font_description_get_weight (desc) > PANGO_WEIGHT_NORMAL)
+				xlsx_add_bool (xml, "b", TRUE);
+			if (pango_font_description_get_style (desc) > PANGO_STYLE_NORMAL)
+				xlsx_add_bool (xml, "i", TRUE);
+		}
+		if (has_font_color) {
+			gsf_xml_out_start_element (xml, "a:solidFill");
+			xlsx_write_rgbarea (xml, style->font.color);
+			gsf_xml_out_end_element (xml);
+		}
+		if (has_font) {
+			gsf_xml_out_start_element (xml, "a:latin");
+			gsf_xml_out_add_cstr (xml, "typeface",
+					      pango_font_description_get_family (desc));
+			gsf_xml_out_end_element (xml);
+		}
+		gsf_xml_out_end_element (xml); /* </a:rPr> */
+	}
+
+	gsf_xml_out_simple_element (xml, "a:t", text);
+
+	gsf_xml_out_end_element (xml); /* </a:r> */
+	gsf_xml_out_end_element (xml); /* </a:p> */
+
+	gsf_xml_out_end_element (xml); /* </c:rich> */
+	gsf_xml_out_end_element (xml); /* </c:tx> */
+
+	xlsx_write_go_style (xml, style);
+
+	g_free (text);
+}
+
+static unsigned
+xlsx_get_axid (XLSXWriteState *state, GogAxis *axis)
+{
+	gpointer l = g_hash_table_lookup (state->axids, axis);
+	if (!l) {
+		l = GUINT_TO_POINTER (1 + g_hash_table_size (state->axids));
+		g_hash_table_insert (state->axids, axis, l);
+	}
+	return GPOINTER_TO_UINT (l);
+}
+
+
+static void
+xlsx_write_axis (XLSXWriteState *state, GsfXMLOut *xml, GogAxis *axis, GogAxisType at)
+{
+	GogAxis *crossed = gog_axis_base_get_crossed_axis (GOG_AXIS_BASE (axis));
+	GogAxisPosition pos;
+	GogGridLine *grid;
+	GogObject *label;
+	GOFormat *format;
+
+#ifdef DEBUG_AXIS
+	g_printerr ("Writing axis %s.  (discrete = %d)\n",
+		    gog_object_get_name (GOG_OBJECT (axis)),
+		    gog_axis_is_discrete (axis));
+#endif
+
+	if (gog_axis_is_discrete (axis))
+		gsf_xml_out_start_element (xml, "c:catAx");
+	else
+		gsf_xml_out_start_element (xml, "c:valAx");
+	xlsx_write_chart_uint (xml, "c:axId", 0, xlsx_get_axid (state, axis));
+	gsf_xml_out_start_element (xml, "c:scaling");
+	xlsx_write_chart_cstr_unchecked (xml, "c:orientation", gog_axis_is_inverted (axis)? "maxMin": "minMax");
+	// TODO: export min, max, an others
+	gsf_xml_out_end_element (xml);
+	/* FIXME position might be "t" or "r" */
+	xlsx_write_chart_cstr_unchecked (xml, "c:axPos", (at == GOG_AXIS_X || at == GOG_AXIS_CIRCULAR)? "b": "l");
+
+	/* grids */
+	grid = gog_axis_get_grid_line (axis, TRUE);
+	if (grid) {
+		gsf_xml_out_start_element (xml, "c:majorGridlines");
+		xlsx_write_go_style (xml, go_styled_object_get_style (GO_STYLED_OBJECT (grid)));
+		gsf_xml_out_end_element (xml);
+	}
+	grid = gog_axis_get_grid_line (axis, FALSE);
+	if (grid) {
+		gsf_xml_out_start_element (xml, "c:minorGridlines");
+		xlsx_write_go_style (xml, go_styled_object_get_style (GO_STYLED_OBJECT (grid)));
+		gsf_xml_out_end_element (xml);
+	}
+
+	label = gog_object_get_child_by_name (GOG_OBJECT (axis), "Label");
+	if (label) {
+		GOData *text = gog_dataset_get_dim (GOG_DATASET (label), 0);
+		if (text != NULL) {
+			gsf_xml_out_start_element (xml, "c:title");
+			xlsx_write_chart_text (state, xml, text, label);
+			gsf_xml_out_end_element (xml);
+		}
+	}
+
+	gsf_xml_out_start_element (xml, "c:numFmt");
+	format = gog_axis_get_format (axis);
+	xlsx_add_bool (xml, "sourceLinked", format == NULL || go_format_is_general (format));
+	format = gog_axis_get_effective_format (axis);
+	gsf_xml_out_add_cstr (xml, "formatCode", (format)? go_format_as_XL (format): "General");
+	gsf_xml_out_end_element (xml);
+
+	xlsx_write_go_style (xml, go_styled_object_get_style (GO_STYLED_OBJECT (axis)));
+
+	xlsx_write_chart_int (xml, "c:crossAx", 0, xlsx_get_axid (state, crossed));
+	g_object_get (G_OBJECT (axis), "pos", &pos, NULL);
+	switch (pos) {
+	default:
+	case GOG_AXIS_AT_LOW:
+		/* FIXME: might be wrong if the axis is inverted */
+		xlsx_write_chart_cstr_unchecked (xml, "c:crosses", "min");
+		break;
+	case GOG_AXIS_CROSS: {
+		double cross = gog_axis_base_get_cross_location (GOG_AXIS_BASE (axis));
+		if (cross == 0.)
+			xlsx_write_chart_cstr_unchecked (xml, "c:crosses", "autoZero");
+		else
+			xlsx_write_chart_float (xml, "c:crossesAt", 0., cross);
+		break;
+	}
+	case GOG_AXIS_AT_HIGH:
+		xlsx_write_chart_cstr_unchecked (xml, "c:crosses", "max");
+		break;
+	}
+
+	/* finished with axis */
+	gsf_xml_out_end_element (xml);
+}
+
+
 static void
 xlsx_write_one_plot (XLSXWriteState *state, GsfXMLOut *xml, GogObject const *chart, GogObject const *plot)
 {
-	char const *plot_type;
-	gboolean failed = FALSE;
-	gboolean use_xy = FALSE;
 	double explosion = 0.;
 	gboolean vary_by_element;
 	GogAxisType axis_type[3] = {GOG_AXIS_X, GOG_AXIS_Y, GOG_AXIS_UNKNOWN};
 	unsigned i;
+	XLSXPlotType plot_type;
+	const char *plot_type_name;
+	GSList const *series;
+	unsigned count;
+	gboolean use_xy = FALSE;
+	gboolean set_smooth = FALSE;
+	gboolean has_markers = FALSE;
 
 	g_object_get (G_OBJECT (plot),
 		      "vary-style-by-element", &vary_by_element,
 		      NULL);
-	plot_type = G_OBJECT_TYPE_NAME (plot);
+	plot_type_name = G_OBJECT_TYPE_NAME (plot);
+	plot_type = xlsx_plottype_from_type_name (plot_type_name);
 
-	if (0 == strcmp (plot_type, "GogAreaPlot")) {
+	switch (plot_type) {
+	default:
+	case XLSX_PT_UNKNOWN:
+		g_warning ("unexpected plot type %s", plot_type_name);
+		return;
+
+	case XLSX_PT_GOGAREAPLOT:
 		gsf_xml_out_start_element (xml, "c:areaChart");
 		xlsx_write_plot_1_5_type (xml, plot, FALSE);
-	} else if (0 == strcmp (plot_type, "GogBarColPlot")) {
+		xlsx_write_chart_bool (xml, "c:varyColors", vary_by_element);
+		break;
+
+	case XLSX_PT_GOGBARCOLPLOT: {
 		gboolean horizontal;
-		int overlap_percentage, gap_percentage;
-		g_object_get (G_OBJECT (plot),
-			"horizontal",		&horizontal,
-			"overlap-percentage",	&overlap_percentage,
-			"gap-percentage",	&gap_percentage,
-			NULL);
+
+		g_object_get (G_OBJECT (plot), "horizontal", &horizontal, NULL);
 		if (horizontal) {
 			axis_type[0] = GOG_AXIS_Y;
 			axis_type[1] = GOG_AXIS_X;
 		}
 		gsf_xml_out_start_element (xml, "c:barChart");
-		gsf_xml_out_simple_element (xml, "c:barDir",
-			horizontal ? "bar" : "col");
+
+		xlsx_write_chart_cstr_unchecked (xml, "c:barDir",
+						 horizontal ? "bar" : "col");
+
 		xlsx_write_plot_1_5_type (xml, plot, TRUE);
+		xlsx_write_chart_bool (xml, "c:varyColors", vary_by_element);
+		break;
+	}
 
-		gsf_xml_out_start_element (xml, "c:overlap");
-		gsf_xml_out_add_int (xml, "val", overlap_percentage);
-		gsf_xml_out_end_element (xml);
-
-		gsf_xml_out_start_element (xml, "c:gapWidth");
-		gsf_xml_out_add_int (xml, "val", gap_percentage);
-		gsf_xml_out_end_element (xml);
-	} else if (0 == strcmp (plot_type, "GogLinePlot")) {
+	case XLSX_PT_GOGLINEPLOT:
 		gsf_xml_out_start_element (xml, "c:lineChart");
 		xlsx_write_plot_1_5_type (xml, plot, FALSE);
-	} else if (0 == strcmp (plot_type, "GogPiePlot") ||
-		   0 == strcmp (plot_type, "GogRingPlot")) {
-		double initial_angle = 0., center_size = 0.;
-		gint16 center = 0;
-		if (0 == strcmp (plot_type, "GogRingPlot")) {
+		xlsx_write_chart_bool (xml, "c:varyColors", vary_by_element);
+		set_smooth = TRUE;
+		g_object_get (G_OBJECT (plot),
+		              "default-style-has-markers", &has_markers,
+		              NULL);
+		break;
+
+	case XLSX_PT_GOGPIEPLOT:
+	case XLSX_PT_GOGRINGPLOT:
+		if (plot_type == XLSX_PT_GOGRINGPLOT) {
+			gint16 center;
+			double center_size;
 			gsf_xml_out_start_element (xml, "c:doughnutChart");
 			g_object_get (G_OBJECT (plot), "center-size", &center_size, NULL);
 			center = (int)floor (center_size * 100. + .5);
 			xlsx_write_chart_int (xml, "c:holeSize", 10,
-				CLAMP (center, 10, 90));
+					      CLAMP (center, 10, 90));
 		} else
 			gsf_xml_out_start_element (xml, "c:pieChart");
 
 		xlsx_write_chart_bool (xml, "c:varyColors", vary_by_element);
-		g_object_get (G_OBJECT (plot),
-			"initial-angle",	 &initial_angle,
-			NULL);
-		xlsx_write_chart_int (xml, "c:firstSliceAng", 0, (int) initial_angle);
 #if 0
 		double default_separation = 0.;
 		/* handled in series ? */
@@ -251,29 +529,25 @@ xlsx_write_one_plot (XLSXWriteState *state, GsfXMLOut *xml, GogObject const *cha
 		xlsx_write_chart_int (xml, "c:explosion", 0, default_separation);
 #endif
 		axis_type[0] = axis_type[1] = GOG_AXIS_UNKNOWN;
-			   g_object_get (G_OBJECT (plot), "default-separation", &explosion, NULL);
-	} else if (0 == strcmp (plot_type, "GogRadarPlot") ||
-		   0 == strcmp (plot_type, "GogRadarAreaPlot")) {
+		g_object_get (G_OBJECT (plot), "default-separation", &explosion, NULL);
+		break;
+
+	case XLSX_PT_GOGRADARPLOT:
+	case XLSX_PT_GOGRADARAREAPLOT:
 		gsf_xml_out_start_element (xml, "c:radarChart");
+		xlsx_write_chart_cstr_unchecked (xml, "c:radarStyle", "standard");
 		axis_type[0] = GOG_AXIS_CIRCULAR;
 		axis_type[1] = GOG_AXIS_RADIAL;
-	} else if (0 == strcmp (plot_type, "GogBubblePlot")) {
-		gboolean show_neg = FALSE, in_3d = FALSE, as_area = TRUE;
-		g_object_get (G_OBJECT (plot),
-			"show-negatives",	&show_neg,
-			"in-3d",		&in_3d,
-			"size-as-area",		&as_area,
-			NULL);
+		break;
+
+	case XLSX_PT_GOGBUBBLEPLOT:
 		gsf_xml_out_start_element (xml, "c:bubbleChart");
 		xlsx_write_chart_bool (xml, "c:varyColors", vary_by_element);
-		xlsx_write_chart_bool (xml, "c:showNegBubbles", show_neg);
-		xlsx_write_chart_cstr_unchecked (xml, "c:sizeRepresents",
-			as_area ? "area" : "w");
-		if (in_3d)
-			xlsx_write_chart_bool (xml, "c:bubble3D", TRUE);
 		use_xy = TRUE;
-	} else if ( 0 == strcmp (plot_type, "GogXYPlot")) {
-		gboolean has_lines, has_markers, use_splines;
+		break;
+
+	case XLSX_PT_GOGXYPLOT: {
+		gboolean has_lines, use_splines;
 		char const *style;
 		g_object_get (G_OBJECT (plot),
 		              "default-style-has-lines", &has_lines,
@@ -286,111 +560,173 @@ xlsx_write_one_plot (XLSXWriteState *state, GsfXMLOut *xml, GogObject const *cha
 					(has_markers? "lineMarker": "line")):
 				(has_markers? "marker": "none");
 		use_xy = TRUE;
+		set_smooth = TRUE;
 		gsf_xml_out_start_element (xml, "c:scatterChart");
 		xlsx_write_chart_cstr_unchecked (xml, "c:scatterStyle", style);
-	} else if (0 == strcmp (plot_type, "GogContourPlot") ||
-		   0 == strcmp (plot_type, "XLContourPlot")) {
-		gsf_xml_out_start_element (xml, "c:surfaceChart");
-	} else {
-		g_warning ("unexpected plot type %s", plot_type);
-		failed = TRUE;
-		axis_type[0] = axis_type[1] = GOG_AXIS_UNKNOWN;
+		xlsx_write_chart_bool (xml, "c:varyColors", vary_by_element);
+		break;
 	}
-	if (!failed) {
-		GSList const *series = gog_plot_get_series (GOG_PLOT (plot));
-		unsigned count = 0;
-		for ( ; NULL != series ; series = series->next) {
-			gsf_xml_out_start_element (xml, "c:ser");
 
-			xlsx_write_chart_int (xml, "c:idx", -1, count);
-			xlsx_write_chart_int (xml, "c:order", -1, count);
-			if (!vary_by_element) /* FIXME: we might loose some style elements */
-				xlsx_write_go_style (xml, go_styled_object_get_style (GO_STYLED_OBJECT (series->data)));
-			xlsx_write_series_dim (state, xml, series->data,
-				"c:tx", GOG_MS_DIM_LABELS);
-			if (use_xy) {
-				xlsx_write_series_dim (state, xml, series->data,
-					"c:yVal", GOG_MS_DIM_VALUES);
-				xlsx_write_series_dim (state, xml, series->data,
-					"c:xVal",  GOG_MS_DIM_CATEGORIES);
-				xlsx_write_series_dim (state, xml, series->data,
-					"c:bubbleSize", GOG_MS_DIM_BUBBLES);
-			} else {
-				xlsx_write_series_dim (state, xml, series->data,
-					"c:val", GOG_MS_DIM_VALUES);
-				xlsx_write_series_dim (state, xml, series->data,
-					"c:cat",  GOG_MS_DIM_CATEGORIES);
-			}
-			if (explosion > 0.)
-				xlsx_write_chart_uint (xml, "c:explosion", 0, (unsigned) (explosion * 100));
-			gsf_xml_out_end_element (xml); /* </c:ser> */
-		}
-		/* write axes Ids */
-		for (i = 0; i < 3; i++)
-			if (axis_type[i] != GOG_AXIS_UNKNOWN)
-				xlsx_write_chart_uint (xml, "c:axId", 0, GPOINTER_TO_UINT (gog_plot_get_axis (GOG_PLOT (plot), axis_type[i])));
-		gsf_xml_out_end_element (xml);
+	case XLSX_PT_GOGCONTOURPLOT:
+	case XLSX_PT_XLCONTOURPLOT:
+		gsf_xml_out_start_element (xml, "c:surfaceChart");
+		break;
 	}
+
+	count = 0;
+	for (series = gog_plot_get_series (GOG_PLOT (plot));
+	     NULL != series;
+	     series = series->next) {
+		GogSeries *ser = series->data;
+		GSList *l, *children;
+		GOStyle *style = go_styled_object_get_style (GO_STYLED_OBJECT (ser));
+
+		gsf_xml_out_start_element (xml, "c:ser");
+
+		xlsx_write_chart_int (xml, "c:idx", -1, count);
+		xlsx_write_chart_int (xml, "c:order", -1, count);
+		xlsx_write_series_dim (state, xml, ser, "c:tx", GOG_MS_DIM_LABELS);
+		if (!vary_by_element) /* FIXME: we might loose some style elements */
+			xlsx_write_go_style_full (xml, style, has_markers);
+
+		children = gog_object_get_children (GOG_OBJECT (ser), NULL);
+		for (l = children; l; l = l->next) {
+			GogObject *trend = l->data;
+			const char *trend_type_name = G_OBJECT_TYPE_NAME (trend);
+			const char *trend_type;
+			GogObject *eq;
+
+			if (!GOG_IS_TREND_LINE (trend))
+				continue;
+
+			if (strcmp (trend_type_name, "GogExpRegCurve") == 0)
+				trend_type = "exp";
+			else if (strcmp (trend_type_name, "GogLinRegCurve") == 0)
+				trend_type = "linear";
+			else if (strcmp (trend_type_name, "GogLogRegCurve") == 0)
+				trend_type = "log";
+			else if (strcmp (trend_type_name, "GogMovingAvg") == 0)
+				trend_type = "movingAvg";
+			else if (strcmp (trend_type_name, "GogPolynomRegCurve") == 0)
+				trend_type = "poly";
+			else if (strcmp (trend_type_name, "GogPowerRegCurve") == 0)
+				trend_type = "power";
+			else {
+				trend_type = "linear";
+				g_warning ("Unknown regression mapped to %s\n", trend_type);
+			}
+
+
+			gsf_xml_out_start_element (xml, "c:trendline");
+			xlsx_write_go_style (xml, go_styled_object_get_style (GO_STYLED_OBJECT (trend)));
+			xlsx_write_chart_cstr_unchecked (xml, "c:trendlineType", trend_type);
+			gsf_xml_out_end_element (xml); /* </c:trendline> */
+
+			eq = gog_object_get_child_by_name (trend, "Equation");
+			if (eq) {
+				gboolean has_r2, has_eq;
+				g_object_get (eq, "show-r2", &has_r2, "show-eq", &has_eq, NULL);
+				if (has_r2)
+					xlsx_write_chart_bool (xml, "c:dispRSqr", TRUE);
+				if (has_eq)
+					xlsx_write_chart_bool (xml, "c:dispEq", TRUE);
+			}
+		}
+		g_slist_free (children);
+
+		if (explosion > 0.)
+			xlsx_write_chart_uint (xml, "c:explosion", 0, (unsigned) (explosion * 100));
+		if (use_xy) {
+			xlsx_write_series_dim (state, xml, ser, "c:xVal", GOG_MS_DIM_CATEGORIES);
+			xlsx_write_series_dim (state, xml, ser, "c:yVal", GOG_MS_DIM_VALUES);
+			xlsx_write_series_dim (state, xml, ser, "c:bubbleSize", GOG_MS_DIM_BUBBLES);
+		} else {
+			xlsx_write_series_dim (state, xml, ser, "c:cat", GOG_MS_DIM_CATEGORIES);
+			xlsx_write_series_dim (state, xml, ser, "c:val", GOG_MS_DIM_VALUES);
+		}
+
+		if (set_smooth) {
+			gboolean smooth;
+			GOLineInterpolation inter;
+			char *s;
+
+			g_object_get (ser, "interpolation", &s, NULL);
+			inter = go_line_interpolation_from_str (s);
+			g_free (s);
+
+			smooth = inter != GO_LINE_INTERPOLATION_LINEAR;
+			xlsx_write_chart_bool (xml, "c:smooth", smooth);
+		}
+
+		gsf_xml_out_end_element (xml); /* </c:ser> */
+	}
+
+	switch (plot_type) {
+	case XLSX_PT_GOGBARCOLPLOT: {
+		int overlap_percentage, gap_percentage;
+
+		g_object_get (G_OBJECT (plot),
+			"overlap-percentage",	&overlap_percentage,
+			"gap-percentage",	&gap_percentage,
+			NULL);
+
+		/* Spec says add "%" at end; XL cannot handle that. */
+		xlsx_write_chart_int (xml, "c:gapWidth", 150, CLAMP (gap_percentage, 0, 500));
+
+		/* Spec says add "%" at end; XL cannot handle that. */
+		xlsx_write_chart_int (xml, "c:overlap", 0, CLAMP (overlap_percentage, 0, 100));
+		break;
+	}
+
+	case XLSX_PT_GOGPIEPLOT:
+	case XLSX_PT_GOGRINGPLOT: {
+		double initial_angle = 0;
+		g_object_get (G_OBJECT (plot),
+			      "initial-angle", &initial_angle,
+			      NULL);
+		xlsx_write_chart_int (xml, "c:firstSliceAng", 0, (int) initial_angle);
+		break;
+	}
+
+	case XLSX_PT_GOGBUBBLEPLOT: {
+		gboolean show_neg = FALSE, in_3d = FALSE, as_area = TRUE;
+		g_object_get (G_OBJECT (plot),
+			      "show-negatives",	&show_neg,
+			      "in-3d",		&in_3d,
+			      "size-as-area",	&as_area,
+			      NULL);
+		if (in_3d)
+			xlsx_write_chart_bool (xml, "c:bubble3D", TRUE);
+		xlsx_write_chart_bool (xml, "c:showNegBubbles", show_neg);
+		xlsx_write_chart_cstr_unchecked (xml, "c:sizeRepresents",
+			as_area ? "area" : "w");
+		break;
+	}
+
+	default:
+		break; /* Nothing */
+	}
+
+	/* write axes Ids */
+	for (i = 0; i < 3; i++)
+		if (axis_type[i] != GOG_AXIS_UNKNOWN)
+			xlsx_write_chart_uint (xml, "c:axId", 0, xlsx_get_axid (state, gog_plot_get_axis (GOG_PLOT (plot), axis_type[i])));
+
+
+	gsf_xml_out_end_element (xml);
+
 	/* Write axes */
 	/* first category axis */
 	/* FIXME: might be a date axis? */
-	for (i = 0; i < 3; i++)
+	for (i = 0; i < 3; i++) {
 		if (axis_type[i] != GOG_AXIS_UNKNOWN) {
 			GSList *axes = gog_chart_get_axes (GOG_CHART (chart), axis_type[i]), *ptr;
 			for (ptr = axes; ptr; ptr = ptr->next) {
-				GogAxis *crossed = gog_axis_base_get_crossed_axis (GOG_AXIS_BASE (ptr->data));
-				GogAxisPosition pos;
-				GogGridLine *grid;
-				if (gog_axis_is_discrete (ptr->data))
-					gsf_xml_out_start_element (xml, "c:catAx");
-				else
-					gsf_xml_out_start_element (xml, "c:valAx");
-				xlsx_write_chart_int (xml, "c:axId", 0, GPOINTER_TO_UINT (ptr->data));
-				gsf_xml_out_start_element (xml, "c:scaling");
-				xlsx_write_chart_cstr_unchecked (xml, "c:orientation", gog_axis_is_inverted (GOG_AXIS (ptr->data))? "maxMin": "minMax");
-				// TODO: export min, max, an others
-				gsf_xml_out_end_element (xml);
-				xlsx_write_go_style (xml, go_styled_object_get_style (GO_STYLED_OBJECT (ptr->data)));
-				/* FIXME position might be "t" or "r" */
-				xlsx_write_chart_cstr_unchecked (xml, "c:axPos", (axis_type[i] == GOG_AXIS_X || axis_type[i] == GOG_AXIS_CIRCULAR)? "b": "l");
-				xlsx_write_chart_int (xml, "c:crossAx", 0, GPOINTER_TO_UINT (crossed));
-				g_object_get (G_OBJECT (ptr->data), "pos", &pos, NULL);
-				switch (pos) {
-				default:
-				case GOG_AXIS_AT_LOW:
-					/* FIXME: might be wrong if the axis is inverted */
-					xlsx_write_chart_cstr_unchecked (xml, "c:crosses", "min");
-					break;
-				case GOG_AXIS_CROSS: {
-					double cross = gog_axis_base_get_cross_location (GOG_AXIS_BASE (ptr->data));
-					if (cross == 0.)
-						xlsx_write_chart_cstr_unchecked (xml, "c:crosses", "autoZero");
-					else
-						xlsx_write_chart_float (xml, "c:crossesAt", 0., cross);
-					break;
-				}
-				case GOG_AXIS_AT_HIGH:
-					xlsx_write_chart_cstr_unchecked (xml, "c:crosses", "max");
-					break;
-				}
-				/* grids */
-				grid = gog_axis_get_grid_line (GOG_AXIS (ptr->data), TRUE);
-				if (grid) {
-					gsf_xml_out_start_element (xml, "c:majorGridlines");
-					xlsx_write_go_style (xml, go_styled_object_get_style (GO_STYLED_OBJECT (grid)));
-					gsf_xml_out_end_element (xml);
-				}
-				grid = gog_axis_get_grid_line (GOG_AXIS (ptr->data), FALSE);
-				if (grid) {
-					gsf_xml_out_start_element (xml, "c:minorGridlines");
-					xlsx_write_go_style (xml, go_styled_object_get_style (GO_STYLED_OBJECT (grid)));
-					gsf_xml_out_end_element (xml);
-				}
-
-				/* finished with axis */
-				gsf_xml_out_end_element (xml);
+				GogAxis *axis = ptr->data;
+				xlsx_write_axis (state, xml, axis, axis_type[i]);
 			}
 		}
+	}
 }
 
 static void
@@ -418,17 +754,27 @@ xlsx_write_one_chart (XLSXWriteState *state, GsfXMLOut *xml, GogObject const *ch
 {
 	GogObject const *obj;
 
-	xlsx_write_go_style (xml, go_styled_object_get_style (GO_STYLED_OBJECT (chart)));
-
 	gsf_xml_out_start_element (xml, "c:chart");
+
+	obj = gog_object_get_child_by_name (chart, "Title");
+	if (obj) {
+		GOData *text = gog_dataset_get_dim (GOG_DATASET (obj), 0);
+		if (text != NULL) {
+			gsf_xml_out_start_element (xml, "c:title");
+			xlsx_write_chart_text (state, xml, text, obj);
+			gsf_xml_out_end_element (xml);
+		}
+	}
+
 	gsf_xml_out_start_element (xml, "c:plotArea");
 	/* save grid style here */
+
+	xlsx_write_plots (state, xml, chart);
+
 	obj = gog_object_get_child_by_name (GOG_OBJECT (chart), "Backplane");
 	if (obj)
 		xlsx_write_go_style (xml, go_styled_object_get_style (GO_STYLED_OBJECT (obj)));
 
-	xlsx_write_plots (state, xml, chart);
-
 	gsf_xml_out_end_element (xml); /* </c:plotArea> */
 
 	if ((obj = gog_object_get_child_by_name (chart, "Legend"))) {
@@ -436,12 +782,14 @@ xlsx_write_one_chart (XLSXWriteState *state, GsfXMLOut *xml, GogObject const *ch
 		gsf_xml_out_end_element (xml); /* </c:legend> */
 	}
 	gsf_xml_out_end_element (xml); /* </c:chart> */
+
+	xlsx_write_go_style (xml, go_styled_object_get_style (GO_STYLED_OBJECT (chart)));
 }
 
 static void
 xlsx_write_chart (XLSXWriteState *state, GsfOutput *chart_part, SheetObject *so)
 {
-	GogGraph const	*graph;
+	GogGraph const *graph;
 	GogObject const	*chart;
 	GsfXMLOut *xml;
 
@@ -474,7 +822,7 @@ xlsx_write_object_anchor (GsfXMLOut *xml, GnmCellPos const *pos, char const *ele
 	/* FIXME: scaling horizontally just like in xlsx_CT_Col */
 	gsf_xml_out_start_element (xml, element);
 	gsf_xml_out_simple_int_element (xml, "xdr:col", pos->col);
-	gsf_xml_out_simple_int_element (xml, "xdr:colOff", 
+	gsf_xml_out_simple_int_element (xml, "xdr:colOff",
 					xlsx_pts_to_emu (col_off_pts * 1.16191275167785));
 	gsf_xml_out_simple_int_element (xml, "xdr:row", pos->row);
 	gsf_xml_out_simple_int_element (xml, "xdr:rowOff",
