@@ -19,10 +19,12 @@
 #include <expr.h>
 #include <value.h>
 #include <gutils.h>
+#include <ranges.h>
 #include <mstyle.h>
 #include <style-color.h>
 #include <style-font.h>
 #include <parse-util.h>
+#include <sheet-style.h>
 #include <sheet-object-cell-comment.h>
 
 #include <gsf/gsf-input.h>
@@ -740,17 +742,35 @@ lotus_format_string (guint fmt)
 }
 
 static void
-cell_set_format_from_lotus_format (GnmCell *cell, guint fmt)
+range_set_format_from_lotus_format (Sheet *sheet,
+				    int scol, int srow,
+				    int ecol, int erow,
+				    guint fmt)
 {
 	char *fmt_string = lotus_format_string (fmt);
-	if (fmt_string[0])
-		gnm_cell_set_format (cell, fmt_string);
+	if (fmt_string[0]) {
+		GnmRange r;
+		GnmStyle *mstyle = gnm_style_new ();
+		gnm_style_set_format_text (mstyle, fmt_string);
+		range_init (&r, scol, srow, ecol, erow);
+		sheet_style_apply_range (sheet, &r, mstyle);
+	}
 #ifdef DEBUG_FORMAT
 	g_printerr ("Format: %s\n", fmt_string);
 #endif
 	g_free (fmt_string);
 }
 
+static void
+cell_set_format_from_lotus_format (GnmCell *cell, guint frmt)
+{
+	range_set_format_from_lotus_format
+		(cell->base.sheet,
+		 cell->pos.col, cell->pos.row,
+		 cell->pos.col, cell->pos.row,
+		 frmt);
+}
+
 /* ------------------------------------------------------------------------- */
 
 static double
@@ -905,18 +925,36 @@ lotus_smallnum (signed int d)
 		return value_new_int (d >> 1);
 }
 
+static GnmValue *
+lotus_extfloat (guint64 mant, guint16 signexp)
+{
+	int exp = (signexp & 0x7fff) - 16383;
+	int sign = (signexp & 0x8000) ? -1 : 1;
+	/* FIXME: Special values may indicate NaN, +/- inf */
+	/*
+	 * NOTE: if gnm_float is "double", then passing the first argument
+	 * to gnm_ldexp will perform rounding from 64-bit integer to
+	 * 53-bit mantissa in a double.
+	 *
+	 * NOTE: the gnm_ldexp may under- or overflow.  That ought to do
+	 * the right thing.
+	 */
+	return lotus_value (sign * gnm_ldexp (mant, exp - 63));
+}
+
+GnmValue *
+lotus_load_treal (gconstpointer p)
+{
+	return lotus_extfloat (GSF_LE_GET_GUINT64 (p),
+			       GSF_LE_GET_GUINT16 ((const char *)p + 8));
+}
+
 static GnmValue *
 lotus_treal (const record_t *r, int ofs)
 {
-	const guint8 *p;
-	gnm_float v;
 	g_return_val_if_fail (ofs + 10 <= r->len, NULL);
 
-	p = r->data + ofs;
-
-	/* This this ignores two bytes of mantissa.  */
-	v = GSF_LE_GET_DOUBLE (p + 2);
-	return lotus_value (v);
+	return lotus_load_treal (r->data + ofs);
 }
 
 /* ------------------------------------------------------------------------- */
@@ -1914,6 +1952,58 @@ lotus_read_new (LotusState *state, record_t *r)
 		case LOTUS_EOF:
 			goto done;
 
+		case LOTUS_FORMAT: CHECK_RECORD_SIZE (>= 2) {
+			Sheet *sheet = lotus_get_sheet (state->wb, r->data[0]);
+			guint8 subtype = GSF_LE_GET_GUINT8 (r->data + 1);
+			switch (subtype) {
+			case 0: CHECK_RECORD_SIZE (>= 4) { // FORMAT
+				int row = GSF_LE_GET_GUINT16 (r->data + 2);
+				int col = 0, o;
+				for (o = 4; o + 4 <= r->len; o += 4) {
+					guint32 frmt = GSF_LE_GET_GUINT32 (r->data + o);
+					gboolean rep = (frmt & 0x80000000u) && (o + 4 < r->len);
+					int n = rep ? 1 + r->data[o++ + 4] : 1;
+					range_set_format_from_lotus_format (sheet,
+									    col, row,
+									    col + (n - 1), row,
+									    frmt);
+					col += n;
+				}
+				break;
+			}
+			case 2: CHECK_RECORD_SIZE (>= 8) { // DUPFMT
+				int row = GSF_LE_GET_GUINT16 (r->data + 2);
+				Sheet *src_sheet = lotus_get_sheet (state->wb, GSF_LE_GET_GUINT16 (r->data + 4));
+				int src_row = GSF_LE_GET_GUINT16 (r->data + 6);
+				GnmRange r;
+				GnmStyleList *styles;
+				GnmCellPos cp;
+
+				range_init_rows (&r, src_sheet, src_row, src_row);
+				styles = sheet_style_get_range (src_sheet, &r);
+
+				cp.col = 0;
+				cp.row = row;
+				sheet_style_set_list  (sheet, &cp, styles, NULL, NULL);
+				style_list_free (styles);
+
+#if 0
+				g_printerr ("%s's row %d copies style from %s's row %d\n",
+					    sheet->name_unquoted, row + 1,
+					    src_sheet->name_unquoted, src_row + 1);
+#endif
+
+				break;
+			}
+
+			case 1: // GBLFMT
+			default:
+				g_printerr ("Unknown format record 0x%x/%02x of length %d.\n",
+					 r->type, subtype, r->len);
+			}
+			break;
+		}
+
 		case LOTUS_ERRCELL: CHECK_RECORD_SIZE (>= 4) {
 			int row = GSF_LE_GET_GUINT16 (r->data);
 			Sheet *sheet = lotus_get_sheet (state->wb, r->data[2]);
@@ -1961,6 +2051,15 @@ lotus_read_new (LotusState *state, record_t *r)
 			break;
 		}
 
+		case LOTUS_EXTENDED_FLOAT: CHECK_RECORD_SIZE (>= 14) {
+			int row = GSF_LE_GET_GUINT16 (r->data);
+			Sheet *sheet = lotus_get_sheet (state->wb, r->data[2]);
+			int col = r->data[3];
+			GnmValue *v = lotus_treal (r, 4);
+			(void)insert_value (state, sheet, col, row, v);
+			break;
+		}
+
 		case LOTUS_STYLE: CHECK_RECORD_SIZE (>= 2) {
 			guint16 subtype = GSF_LE_GET_GUINT16 (r->data);
 			switch (subtype) {
