@@ -76,7 +76,7 @@ static struct {
 		N_("Functions and X-Base importing.") },
 	{ N_("Michel Berkelaar"),		GNM_ANALYTICS,
 		N_("Simplex algorithm for Solver (LP Solve).") },
-	{ N_("Jean Brefort"),		GNM_CORE | GNM_FEATURE_HACKER,
+	{ N_("Jean Br\xc3\xa9""fort"),		GNM_CORE | GNM_FEATURE_HACKER,
 		N_("Core charting engine.") },
 	{ N_("Grandma Chema Celorio"),	GNM_FEATURE_HACKER|GNM_USABILITY|GNM_QA,
 		N_("Quality Assurance and sheet copy.") },
@@ -96,12 +96,14 @@ static struct {
 	        N_("LP-solve") },
 	{ N_("Gergo Erdi"),			GNM_GUI,
 		N_("Custom UI tools") },
+	{ N_("Jody Goldberg"), GNM_CORE, NULL },
 	{ N_("John Gotts"),			GNM_PACKAGING,
 		N_("RPM packaging") },
 	{ N_("Andreas J. G\xc3\xbclzow"),	GNM_CORE|GNM_FEATURE_HACKER|GNM_ANALYTICS|GNM_IMPORT_EXPORT|GNM_GUI|GNM_USABILITY|GNM_DOCUMENTATION|GNM_TRANSLATION|GNM_QA,
 		N_("Statistics and GUI master") },
 	{ N_("Jon K\xc3\xa5re Hellan"),	GNM_CORE|GNM_FEATURE_HACKER|GNM_ANALYTICS|GNM_IMPORT_EXPORT|GNM_SCRIPTING|GNM_GUI|GNM_USABILITY|GNM_DOCUMENTATION|GNM_TRANSLATION|GNM_QA,
 		N_("UI polish and all round bug fixer") },
+	{ N_("Miguel de Icaza"), GNM_CORE, NULL },
 	{ N_("Ross Ihaka"),			GNM_ANALYTICS,
 		N_("Special functions") },
 	{ N_("Jukka-Pekka Iivonen"),	GNM_ANALYTICS|GNM_GUI|GNM_FEATURE_HACKER,
@@ -194,35 +196,6 @@ struct AboutState_ {
 
 /* ---------------------------------------- */
 
-static GdkRGBA
-blend_colors (const GdkRGBA *start, const GdkRGBA *end, double f)
-{
-	GdkRGBA res;
-	res.red   = start->red   * (1 - f) + end->red   * f;
-	res.green = start->green * (1 - f) + end->green * f;
-	res.blue  = start->blue  * (1 - f) + end->blue  * f;
-	res.alpha = start->alpha * (1 - f) + end->alpha * f;
-	return res;
-}
-
-
-static void
-set_fade (AboutRenderer *r, AboutState *state, double f)
-{
-	GtkStyleContext *ctxt = gtk_widget_get_style_context (state->anim_area);
-	PangoAttrList *attrlist = pango_layout_get_attributes (r->layout);
-	GdkRGBA col, bg, fg;
-	PangoAttribute *attr;
-
-	gtk_style_context_get_color (ctxt, GTK_STATE_FLAG_NORMAL, &fg);
-	gtk_style_context_get_background_color (ctxt, GTK_STATE_FLAG_NORMAL, &bg);
-	col = blend_colors (&bg, &fg, f);
-	attr = pango_attr_foreground_new
-		(col.red * 65535., col.green * 65535., col.blue * 65535.);
-	pango_attr_list_change (attrlist, attr);
-	pango_layout_set_attributes (r->layout, attrlist);
-}
-
 static void
 free_renderer (AboutRenderer *r)
 {
@@ -244,14 +217,15 @@ text_item_renderer (AboutRenderer *r, AboutState *state)
 	cairo_t *cr;
 	GtkAllocation wa;
 	GdkRGBA color;
+	double alpha = 1;
 
 	if (age >= r->duration)
 		return FALSE;
 
 	if (r->fade_in && age < fade)
-		set_fade (r, state, age / (double)fade);
+		alpha = age / (double)fade;
 	else if (r->fade_out && r->duration - age < fade)
-		set_fade (r, state, (r->duration - age) / (double)fade);
+		alpha = (r->duration - age) / (double)fade;
 
 	ctxt = gtk_widget_get_style_context (widget);
 
@@ -294,6 +268,7 @@ text_item_renderer (AboutRenderer *r, AboutState *state)
 
 	cr = r->cr;
 	gtk_style_context_get_color (ctxt, GTK_STATE_FLAG_NORMAL, &color);
+	color.alpha = alpha;
 	gdk_cairo_set_source_rgba (cr, &color);
 	cairo_move_to (cr, x / (double)PANGO_SCALE, y / (double)PANGO_SCALE);
 	pango_cairo_show_layout (cr, layout);
@@ -569,7 +544,7 @@ dialog_about (WBCGtk *wbcg)
 			  "website", "http://www.gnumeric.org/",
 			  "website-label", _("Visit the Gnumeric website"),
 			  "logo-icon-name", "gnumeric",
-			  "copyright", _("Copyright \xc2\xa9 1998-2014"),
+			  "copyright", _("Copyright \xc2\xa9 1998-2015"),
 			  "comments", _("Free, Fast, Accurate - Pick Any Three!"),
 			  NULL);
 	state->dialog = w;
@@ -588,9 +563,9 @@ dialog_about (WBCGtk *wbcg)
 		PangoLayout *layout;
 
 		state->anim_area = gtk_drawing_area_new ();
-		layout = gtk_widget_create_pango_layout (state->anim_area, NULL);
+		layout = gtk_widget_create_pango_layout (state->anim_area, "x");
 		pango_layout_get_pixel_size (layout, NULL, &height);
-		gtk_widget_set_size_request (state->anim_area, -1, 4 * height);
+		gtk_widget_set_size_request (state->anim_area, -1, 8 * height);
 		g_object_unref (layout);
 
 		g_signal_connect (state->anim_area, "draw",
