@@ -690,7 +690,7 @@ run_solver (SolverState *state, GnmSolverParameters *param)
 
 	state->run.ok_button =
 		go_gtk_dialog_add_button (dialog,
-					  _("OK"),
+					  GNM_STOCK_OK,
 					  GTK_STOCK_OK,
 					  GTK_RESPONSE_YES);
 
@@ -718,7 +718,7 @@ run_solver (SolverState *state, GnmSolverParameters *param)
 		w = gtk_label_new ("");
 		gtk_widget_set_size_request
 			(w,
-			 gnm_widget_measure_string (w, "0") * (5 + GNM_DIG),
+			 gnm_widget_measure_string (w, "0") * (10 + GNM_DIG),
 			 -1);
 		gtk_grid_attach (GTK_GRID (grid), w, 1, y, 1, 1);
 		switch (y) {
