@@ -13,7 +13,6 @@ G_BEGIN_DECLS
 	void name (GtkAction *a, WBCGtk *wbcg)
 
 GtkWidget* gnumeric_go_error_info_dialog_create (GOErrorInfo *error);
-GtkWidget* gnumeric_go_error_info_list_dialog_create (GSList *errs);
 void       gnumeric_go_error_info_dialog_show (GtkWindow *parent,
 					       GOErrorInfo *error);
 void       gnumeric_go_error_info_list_dialog_show (GtkWindow *parent,
@@ -68,7 +67,7 @@ void gnumeric_create_popup_menu (GnumericPopupMenuElement const *elements,
 				 int sensitive_filter,
 				 GdkEvent *event);
 
-#define gnumeric_filter_modifiers(a) ((a) &(~(GDK_LOCK_MASK|GDK_MOD2_MASK|GDK_MOD5_MASK)))
+#define gnumeric_filter_modifiers(a) ((a) & (GDK_MODIFIER_MASK & (~(GDK_LOCK_MASK|GDK_MOD2_MASK|GDK_MOD5_MASK))))
 
 void gnumeric_init_help_button	(GtkWidget *w, char const *link);
 
@@ -99,9 +98,6 @@ gboolean entry_to_int	(GtkEntry *entry, gint *the_int, gboolean update);
 void	 float_to_entry	(GtkEntry *entry, gnm_float the_float);
 void	 int_to_entry	(GtkEntry *entry, gint the_int);
 
-GtkWidget *gnumeric_load_image  (char const *name);
-GdkPixbuf *gnumeric_load_pixbuf (char const *name);
-
 void gnm_link_button_and_entry (GtkWidget *button, GtkWidget *entry);
 
 void gnm_widget_set_cursor_type (GtkWidget *w, GdkCursorType ct);
@@ -144,6 +140,28 @@ void
 gnm_cell_renderer_text_copy_background_to_cairo (GtkCellRendererText *crt,
 						 cairo_t *cr);
 
+
+/*
+ * These macros exist to replace the old gtk+ stock items.  Note, that these only
+ * cover strings with mnemonics.  I.e., you must handle icons and accelerators
+ * in some other way.  (So why do we have them in the first place?  To ensure
+ * the user interface is as consistent as possible.)
+ */
+#define GNM_STOCK_OPEN g_dpgettext2(GETTEXT_PACKAGE, "Stock label", GNM_N_STOCK_OPEN)
+#define GNM_N_STOCK_OPEN NC_("Stock label", "_Open")
+
+#define GNM_STOCK_SAVE g_dpgettext2(GETTEXT_PACKAGE, "Stock label", GNM_N_STOCK_SAVE)
+#define GNM_N_STOCK_SAVE NC_("Stock label", "_Save")
+
+#define GNM_STOCK_SAVE_AS g_dpgettext2(GETTEXT_PACKAGE, "Stock label", GNM_N_STOCK_SAVE_AS)
+#define GNM_N_STOCK_SAVE_AS NC_("Stock label", "Save _As")
+
+#define GNM_STOCK_CANCEL g_dpgettext2(GETTEXT_PACKAGE, "Stock label", GNM_N_STOCK_CANCEL)
+#define GNM_N_STOCK_CANCEL NC_("Stock label", "_Cancel")
+
+#define GNM_STOCK_OK g_dpgettext2(GETTEXT_PACKAGE, "Stock label", GNM_N_STOCK_OK)
+#define GNM_N_STOCK_OK NC_("Stock label", "_OK")
+
 G_END_DECLS
 
 #endif /* _GNM_GUI_UTIL_H_ */
