@@ -58,7 +58,7 @@ struct _GnmItemBar {
 	/* [ColRowSelectionType] */
 	GdkRGBA selection_colors[3];
 	PangoFont *selection_fonts[3];
-	int selection_font_ascents[3];      
+	int selection_font_ascents[3];
 	PangoRectangle selection_logical_sizes[3];
 
 	GdkRGBA grouping_color;
@@ -152,6 +152,15 @@ ib_reload_sizing_style (GnmItemBar *ib)
 		gtk_style_context_get (context, state, "font", &desc, NULL);
 		pango_font_description_set_size (desc,
 						 zoom_factor * pango_font_description_get_size (desc));
+		ib->selection_fonts[ui] =
+			pango_context_load_font (pcontext, desc);
+		if (!ib->selection_fonts[ui]) {
+			/* Fallback. */
+			pango_font_description_set_family (desc, "Sans");
+			ib->selection_fonts[ui] =
+				pango_context_load_font (pcontext, desc);
+		}
+
 		/*
 		 * Figure out how tall the label can be.
 		 * (Note that we avoid J/Q/Y which may go below the line.)
@@ -159,8 +168,6 @@ ib_reload_sizing_style (GnmItemBar *ib)
 		pango_layout_set_text (layout,
 				       char_label ? "AHW" : "0123456789",
 				       -1);
-		ib->selection_fonts[ui] =
-			pango_context_load_font (pcontext, desc);
 		pango_layout_set_font_description (layout, desc);
 		pango_font_description_free (desc);
 		pango_layout_get_extents (layout, &ink_rect, NULL);
@@ -285,7 +292,7 @@ item_bar_realize (GocItem *item)
 	ib->normal_cursor =
 		gdk_cursor_new_for_display (display, GDK_LEFT_PTR);
 	ib->change_cursor =
-		gdk_cursor_new_for_display (display, 
+		gdk_cursor_new_for_display (display,
 					    ib->is_col_header
 					    ? GDK_SB_H_DOUBLE_ARROW
 					    : GDK_SB_V_DOUBLE_ARROW);
