@@ -209,8 +209,8 @@ item_grid_realize (GocItem *item)
 	display = gtk_widget_get_display (GTK_WIDGET (item->canvas));
 	ig->cursor_link  = gdk_cursor_new_for_display (display, GDK_HAND2);
 	cursor_cross_pixbuf =
-		gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
-					  "cursor_cross", 32, 0, NULL);
+		gtk_icon_theme_load_icon (gtk_icon_theme_get_for_screen (gtk_widget_get_screen (GTK_WIDGET (item->canvas))),
+					  "cursor-cross", 32, 0, NULL);
 	ig->cursor_cross =
 		gdk_cursor_new_from_pixbuf (display,
 					    cursor_cross_pixbuf,
@@ -980,7 +980,7 @@ item_grid_button_pressed (GocItem *item, int button, double x_, double y_)
 	/* Button == 1 is used to trigger hyperlinks (and possibly similar */
 	/* special cases. Otherwise button == 2 should behave exactly like */
 	/* button == 1. See bug #700792                                    */
-	
+
 	/* buttons 1 and 2 will always change the selection,  the other buttons will
 	 * only effect things if the target is not already selected.  */
 	already_selected = sv_is_pos_selected (sv, pos.col, pos.row);
@@ -988,7 +988,7 @@ item_grid_button_pressed (GocItem *item, int button, double x_, double y_)
 		if (!(event->button.state & (GDK_CONTROL_MASK|GDK_SHIFT_MASK)))
 			sv_selection_reset (sv);
 
-		if ((event->button.button != 1 && event->button.button != 2) 
+		if ((event->button.button != 1 && event->button.button != 2)
 		    || !(event->button.state & GDK_SHIFT_MASK) ||
 		    sv->selections == NULL) {
 			sv_selection_add_pos (sv, pos.col, pos.row,
