@@ -207,8 +207,9 @@ gnm_soi_new_view (SheetObject *so, SheetObjectViewContainer *container)
 			NULL));
 
 	} else {
-		GdkPixbuf *placeholder = go_gdk_pixbuf_load_from_file
-			("res:gnm:pixmaps/unknown_image.png");
+		GdkPixbuf *placeholder =
+			gdk_pixbuf_new_from_resource ("/org/gnumeric/gnumeric/images/unknown_image.png",
+						      NULL);
 		GdkPixbuf *pixbuf = gdk_pixbuf_copy (placeholder);
 
 		goc_item_hide (goc_item_new (GOC_GROUP (item),
@@ -281,7 +282,7 @@ gnm_soi_get_target_list (SheetObject const *so)
 }
 
 static void
-gnm_soi_write_image (SheetObject const *so, char const *format, 
+gnm_soi_write_image (SheetObject const *so, char const *format,
 		     G_GNUC_UNUSED double resolution,
 		     GsfOutput *output, GError **err)
 {
@@ -361,7 +362,7 @@ static void
 gnm_soi_populate_menu (SheetObject *so, GPtrArray *actions)
 {
 	static SheetObjectAction const soi_action =
-		{ GTK_STOCK_SAVE_AS, N_("_Save as image"), NULL, 0, soi_cb_save_as };
+		{ "document-save-as", N_("_Save As Image"), NULL, 0, soi_cb_save_as };
 	gnm_soi_parent_class->populate_menu (so, actions);
 	go_ptr_array_insert (actions, (gpointer) &soi_action, 1);
 }
