@@ -38,6 +38,7 @@
 #include "gnm-marshalers.h"
 #include "style-color.h"
 #include "sheet-style.h"
+#include "sheet-object-graph.h"
 
 #include <goffice/goffice.h>
 
@@ -110,6 +111,20 @@ workbook_update_history (Workbook *wb, GnmFileSaveAsStyle type)
 	}
 }
 
+void
+workbook_update_graphs (Workbook *wb)
+{
+	WORKBOOK_FOREACH_SHEET (wb, sheet, ({
+		GSList *l, *graphs = sheet_objects_get (sheet, NULL, SHEET_OBJECT_GRAPH_TYPE);
+		for (l = graphs; l; l = l->next) {
+			SheetObject *sog = l->data;
+			gog_graph_force_update (sheet_object_graph_get_gog (sog));
+		}
+		g_slist_free (graphs);
+	}));
+}
+
+
 static void
 workbook_dispose (GObject *wb_object)
 {
@@ -548,7 +563,7 @@ workbook_foreach_cell_in_range (GnmEvalPos const *pos,
 
 	g_return_val_if_fail (pos != NULL, NULL);
 	g_return_val_if_fail (cell_range != NULL, NULL);
-	g_return_val_if_fail (cell_range->type == VALUE_CELLRANGE, NULL);
+	g_return_val_if_fail (VALUE_IS_CELLRANGE (cell_range), NULL);
 
 	gnm_rangeref_normalize (&cell_range->v_range.cell, pos,
 		&start_sheet, &end_sheet, &r);
