@@ -19,31 +19,26 @@ my $file = "$samples/rich-text-tests.gnumeric";
 &test_roundtrip ($file,
 		 'format' => 'Gnumeric_OpenCalc:odf',
 		 'ext' => "ods",
-		 'filter2' => "$PERL -p -e '\$_ = \"\" if m{<meta:generator>}'");
-
-my $xls_codepage_filter = "$PERL -p -e '\$_ = \"\" if m{<meta:user-defined meta:name=.msole:codepage.}'";
-
-# xls cannot have superscript and subscript at the same time
-my $xls_supersub_filter = "$PERL -p -e 's{\\[superscript=1:3:5\\]\\[subscript=1:4:5\\]}{[superscript=1:3:4][subscript=1:4:5]};'";
+		 'filter2' => 'std:drop_generator');
 
 &message ("Check rich text xls/BIFF7 roundtrip.");
 &test_roundtrip ($file,
 		 'format' => 'Gnumeric_Excel:excel_biff7',
 		 'ext' => "xls",
 		 'resize' => '16384x256',
-		 'filter1' => $xls_supersub_filter,
-		 'filter2' => $xls_codepage_filter);
+		 'filter1' => "std:supersub | std:no_author | std:no_rich_comment",
+		 'filter2' => 'std:drop_codepage');
 
 &message ("Check rich text xls/BIFF8 roundtrip.");
 &test_roundtrip ($file,
 		 'format' => 'Gnumeric_Excel:excel_biff8',
 		 'ext' => "xls",
-		 'filter1' => $xls_supersub_filter,
-		 'filter2' => $xls_codepage_filter);
+		 'filter1' => 'std:supersub',
+		 'filter2' => 'std:drop_codepage');
 
 &message ("Check rich text xlsx roundtrip.");
 &test_roundtrip ($file,
 		 'format' => 'Gnumeric_Excel:xlsx',
 		 'ext' => "xlsx",
 		 'resize' => '1048576x16384',
-		 'filter1' => $xls_supersub_filter);
+		 'filter1' => 'std:supersub');
